package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletConfig;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 全局配置Mapper接口
 *
 * @author ruoyi
 * @date 2024-06-04
 */
public interface PlayletConfigMapper extends BaseMapper<PlayletConfig>
{
    /**
     * 查询全局配置
     *
     * @param id 全局配置主键
     * @return 全局配置
     */
    public PlayletConfig selectPlayletConfigById(Long id);

    /**
     * 查询全局配置列表
     *
     * @param playletConfig 全局配置
     * @return 全局配置集合
     */
    public List<PlayletConfig> selectPlayletConfigList(PlayletConfig playletConfig);

    /**
     * 新增全局配置
     *
     * @param playletConfig 全局配置
     * @return 结果
     */
    public int insertPlayletConfig(PlayletConfig playletConfig);

    /**
     * 修改全局配置
     *
     * @param playletConfig 全局配置
     * @return 结果
     */
    public int updatePlayletConfig(PlayletConfig playletConfig);

    /**
     * 删除全局配置
     *
     * @param id 全局配置主键
     * @return 结果
     */
    public int deletePlayletConfigById(Long id);

    /**
     * 批量删除全局配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletConfigByIds(String[] ids);
}
